LetExtension<T, R> extension

Extension on T? to add a let method.

on
  • T?

Methods

let(R block(T)) → R?

Available on T?, provided by the LetExtension extension

Applies the block function to this value and returns the result if this value is not null.