VoidClosure<T> typedef

VoidClosure<T> = void Function(T value)

A function type alias for a closure that takes an argument of type T and returns void.

This is a generic function type where T is the type of the argument.

Example usage:

VoidClosure<int> printNumber = (int number) {
  print('Number is: $number');
};
printNumber(5); // prints: 'Number is: 5'

Implementation

typedef VoidClosure<T> = void Function(T value);