or method
Returns the boolean if it's not null, otherwise it returns a default value.
defaultValue is the value to be returned when the boolean is null.
The default value is false.
Implementation
bool or({bool defaultValue = false}) {
return this ?? defaultValue;
}